@@ -52,44 +52,64 @@ class KodeKronicalDaemon:
         # Set up paths based on config
         daemon_config = self.config.get('daemon', {})
         
-        # Determine if we're running as root/system or user
-        self.is_system_daemon = os.geteuid() == 0 if hasattr(os, 'geteuid') else False
+        # Always use user directory to avoid permission issues
+        home = Path.home()
+        default_pid_file = str(home / '.local/share/kode-kronical/daemon.pid')
+        default_log_file = str(home / '.local/share/kode-kronical/daemon.log')
+        default_data_dir = str(home / '.local/share/kode-kronical')
         
-        # Set default paths based on daemon type
-        if self.is_system_daemon:
-            # System daemon paths
-            default_pid_file = '/var/run/kode-kronical-daemon.pid'
-            default_log_file = '/var/log/kode-kronical-daemon.log'
-            default_data_dir = '/var/lib/kode-kronical'
-        else:
-            # User daemon paths
-            home = Path.home()
-            default_pid_file = str(home / '.local/share/kode-kronical/daemon.pid')
-            default_log_file = str(home / '.local/share/kode-kronical/daemon.log')
-            default_data_dir = str(home / '.local/share/kode-kronical')
+        # Get paths from config and expand ~ to user home
+        pid_path = daemon_config.get('pid_file', default_pid_file)
+        log_path = daemon_config.get('log_file', default_log_file)
+        data_path = daemon_config.get('data_dir', default_data_dir)
         
-        self.pid_file = Path(daemon_config.get('pid_file', default_pid_file))
-        self.log_file = Path(daemon_config.get('log_file', default_log_file))
-        self.data_dir = Path(daemon_config.get('data_dir', default_data_dir))
+        # Expand ~ in paths
+        self.pid_file = Path(os.path.expanduser(pid_path))
+        self.log_file = Path(os.path.expanduser(log_path))
+        self.data_dir = Path(os.path.expanduser(data_path))
         
-        # Create directories if they don't exist
-        self.data_dir.mkdir(parents=True, exist_ok=True)
-        self.log_file.parent.mkdir(parents=True, exist_ok=True)
-        self.pid_file.parent.mkdir(parents=True, exist_ok=True)
+        # Create directories - should always work since we're using user directories
+        try:
+            self.data_dir.mkdir(parents=True, exist_ok=True)
+            self.log_file.parent.mkdir(parents=True, exist_ok=True)
+            self.pid_file.parent.mkdir(parents=True, exist_ok=True)
+            print(f"Using data directory: {self.data_dir}")
+        except Exception as e:
+            print(f"FATAL: Cannot create user directories: {e}")
+            print(f"Attempted paths: data={self.data_dir}, log={self.log_file.parent}, pid={self.pid_file.parent}")
+            raise
         
-        # Set up logging
-        logging.basicConfig(
-            filename=str(self.log_file),
-            level=logging.INFO,
-            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
-        )
+        # Set up logging with error handling
+        try:
+            logging.basicConfig(
+                filename=str(self.log_file),
+                level=logging.INFO,
+                format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+            )
+            print(f"Logging initialized to: {self.log_file}")
+        except Exception as e:
+            print(f"Error setting up logging to {self.log_file}: {e}")
+            # Fall back to console logging
+            logging.basicConfig(
+                level=logging.INFO,
+                format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
+            )
+            print("Falling back to console logging")
         self.logger = logging.getLogger('kode-kronical-daemon')
         
         # Initialize system monitor
-        self.monitor = SystemMonitor(
-            sample_interval=daemon_config.get('sample_interval', 1.0),
-            max_samples=daemon_config.get('max_samples', 3600)
-        )
+        try:
+            print("Initializing SystemMonitor...")
+            self.monitor = SystemMonitor(
+                sample_interval=daemon_config.get('sample_interval', 1.0),
+                max_samples=daemon_config.get('max_samples', 3600)
+            )
+            print("SystemMonitor initialized successfully")
+        except Exception as e:
+            print(f"FATAL: Failed to initialize SystemMonitor: {e}")
+            import traceback
+            traceback.print_exc()
+            raise
         
         # Initialize DynamoDB service if enabled
         self.dynamodb_service = None
@@ -138,87 +158,127 @@ class KodeKronicalDaemon:
             }
         }
     
-    def start(self):
-        """Start the daemon."""
-        # Check if already running
-        if self.is_running():
-            print(f"Daemon already running with PID {self.get_pid()}")
-            return
+    def start(self, foreground=False):
+        """Start the daemon.
         
-        print("Starting kode-kronical-daemon...")
-        
-        # Fork and daemonize
-        if os.name != 'nt':  # Unix/Linux/macOS
-            self._daemonize()
-        
-        # Write PID file
-        with open(self.pid_file, 'w') as f:
-            f.write(str(os.getpid()))
-        
-        # Set up signal handlers
-        signal.signal(signal.SIGTERM, self._signal_handler)
-        signal.signal(signal.SIGINT, self._signal_handler)
-        
-        # Start monitoring
-        self.running = True
-        self.monitor.start_monitoring()
-        
-        self.logger.info(f"Daemon started with PID {os.getpid()}")
-        
-        # Register this system in the registry
-        if self.registry_service:
+        Args:
+            foreground: If True, run in foreground (don't fork)
+        """
+        try:
+            # Check if already running
+            if self.is_running():
+                print(f"Daemon already running with PID {self.get_pid()}")
+                return
+            
+            print("Starting kode-kronical-daemon...")
+            
+            # Fork and daemonize only if not running in foreground
+            if not foreground and os.name != 'nt':  # Unix/Linux/macOS
+                print("Daemonizing (forking)...")
+                self._daemonize()
+            else:
+                print("Running in foreground mode")
+            
+            # Write PID file
+            print(f"Writing PID {os.getpid()} to {self.pid_file}")
+            with open(self.pid_file, 'w') as f:
+                f.write(str(os.getpid()))
+            
+            # Set up signal handlers
+            print("Setting up signal handlers...")
+            signal.signal(signal.SIGTERM, self._signal_handler)
+            signal.signal(signal.SIGINT, self._signal_handler)
+            
+            # Start monitoring
+            print("Setting running = True and starting monitor...")
+            self.running = True
+            
             try:
-                import platform
-                hostname = get_normalized_hostname()
-                self.registry_service.register_system(
-                    hostname=hostname,
-                    platform_info=platform.system()
-                )
-                self.logger.info(f"Registered system {hostname} in registry")
+                self.monitor.start_monitoring()
+                print("Monitor started successfully")
             except Exception as e:
-                self.logger.error(f"Failed to register system: {e}")
-        
-        # Main loop
-        metrics_buffer = []
-        last_save = time.time()
-        save_interval = 60  # Save every minute
-        
-        while self.running:
-            try:
-                # Get current metrics
-                metrics = self.monitor.get_current_metrics()
-                if metrics:
-                    metrics_buffer.append(metrics)
-                
-                # Save periodically
-                if time.time() - last_save >= save_interval:
-                    if metrics_buffer:
-                        self._save_metrics(metrics_buffer)
-                        metrics_buffer = []
-                    last_save = time.time()
+                print(f"FATAL: Failed to start monitor: {e}")
+                import traceback
+                traceback.print_exc()
+                return
+            
+            self.logger.info(f"Daemon started with PID {os.getpid()}")
+            print(f"Daemon started with PID {os.getpid()}")
+            
+            # Register this system in the registry
+            if self.registry_service:
+                try:
+                    import platform
+                    hostname = get_normalized_hostname()
+                    self.registry_service.register_system(
+                        hostname=hostname,
+                        platform_info=platform.system()
+                    )
+                    self.logger.info(f"Registered system {hostname} in registry")
+                except Exception as e:
+                    self.logger.error(f"Failed to register system: {e}")
+            
+            # Main loop
+            print("Starting main monitoring loop...")
+            metrics_buffer = []
+            last_save = time.time()
+            save_interval = 60  # Save every minute
+            
+            while self.running:
+                try:
+                    # Get current metrics
+                    metrics = self.monitor.get_current_metrics()
+                    if metrics:
+                        metrics_buffer.append(metrics)
                     
-                    # Cleanup old files
-                    self._cleanup_old_files()
-                
-                time.sleep(1)
-                
-            except Exception as e:
-                self.logger.error(f"Error in daemon main loop: {e}")
-                time.sleep(5)
-        
-        # Clean up
-        self.monitor.stop_monitoring()
-        
-        # Mark system as offline in registry
-        if self.registry_service:
+                    # Save periodically
+                    if time.time() - last_save >= save_interval:
+                        if metrics_buffer:
+                            self._save_metrics(metrics_buffer)
+                            metrics_buffer = []
+                        last_save = time.time()
+                        
+                        # Cleanup old files
+                        self._cleanup_old_files()
+                    
+                    time.sleep(1)
+                    
+                except Exception as e:
+                    print(f"ERROR in main loop: {e}")
+                    import traceback
+                    traceback.print_exc()
+                    self.logger.error(f"Error in daemon main loop: {e}")
+                    time.sleep(5)
+            
+            # Clean up
+            print("Main loop exited, cleaning up...")
+            print(f"Running state when exiting: {self.running}")
+            self.monitor.stop_monitoring()
+            
+            # Mark system as offline in registry
+            if self.registry_service:
+                try:
+                    hostname = get_normalized_hostname()
+                    self.registry_service.mark_system_offline(hostname)
+                except Exception as e:
+                    self.logger.error(f"Failed to mark system offline: {e}")
+            
+            if os.path.exists(self.pid_file):
+                os.unlink(self.pid_file)
+            self.logger.info("Daemon stopped")
+            print("Daemon cleanup completed")
+            
+        except Exception as e:
+            print(f"FATAL EXCEPTION in start(): {e}")
+            import traceback
+            traceback.print_exc()
+            # Make sure we clean up the PID file even on fatal error
             try:
-                hostname = get_normalized_hostname()
-                self.registry_service.mark_system_offline(hostname)
-            except Exception as e:
-                self.logger.error(f"Failed to mark system offline: {e}")
-        
-        os.unlink(self.pid_file)
-        self.logger.info("Daemon stopped")
+                if hasattr(self, 'pid_file') and os.path.exists(self.pid_file):
+                    os.unlink(self.pid_file)
+            except:
+                pass
+            raise
     
     def stop(self):
         """Stop the daemon."""
@@ -326,6 +386,7 @@ class KodeKronicalDaemon:
     
     def _signal_handler(self, signum, frame):
         """Handle shutdown signals."""
+        print(f"SIGNAL RECEIVED: {signum} - shutting down...")
         self.logger.info(f"Received signal {signum}, shutting down...")
         self.running = False
     
@@ -421,6 +482,9 @@ Config file locations (searched in order):
     parser.add_argument('--system', action='store_true',
                        help='Install as system service (requires root)')
     
+    parser.add_argument('--foreground', action='store_true',
+                       help='Run in foreground (do not fork)')
+    
     args = parser.parse_args()
     
     # Handle special commands
@@ -451,7 +515,7 @@ Config file locations (searched in order):
     
     # Execute command
     if args.command == 'start':
-        daemon.start()
+        daemon.start(foreground=args.foreground)
     elif args.command == 'stop':
         daemon.stop()
     elif args.command == 'restart':
@@ -477,9 +541,9 @@ def generate_config(args):
         # System config
         config_dir = Path('/etc/kode-kronical')
         config_file = config_dir / 'daemon.yaml'
-        data_dir = Path('/var/lib/kode-kronical')
+        data_dir = Path.home() / '.local' / 'share' / 'kode-kronical'
         log_file = Path('/var/log/kode-kronical-daemon.log')
-        pid_file = Path('/var/run/kode-kronical-daemon.pid')
+        pid_file = Path.home() / '.local' / 'share' / 'kode-kronical' / 'daemon.pid'
     
     config_template = f"""# KodeKronical Daemon Configuration
 daemon:
@@ -651,7 +715,7 @@ Description=KodeKronical System Monitoring Daemon
 After=network.target
 
 [Service]
-Type=forking
+Type=simple
 ExecStart={daemon_cmd} -c {config_file} start
 ExecStop={daemon_cmd} -c {config_file} stop
 ExecReload={daemon_cmd} -c {config_file} restart
